TransferMatrix

Struct TransferMatrix 

pub struct TransferMatrix {
    pub t22: Complex<f64>,
    /* private fields */
}
Struct representing the transfer matrix.

Fields

t22: Complex<f64>

t22 element of the matrix.

Implementations

Source

impl TransferMatrix

pub fn compose(self, other: TransferMatrix) -> TransferMatrix

Returns a new TransferMatrix which is the composition of two matrices..

Arguments:
  • other - The other matrix to compose with.
Returns:

The composition of the two matrices.

pub fn matrix_start() -> TransferMatrix

Creates the idendity transfer matrix. Useful to start the recursion..

Returns:

The identity transfer matrix.

pub fn matrix_propagation(n: f64, d: f64, k0: f64, k: f64) -> TransferMatrix

Creates the transfer matrix for a homogeneous layer.

Arguments:
  • n - The refractive index of the layer.
  • d - The thickness of the layer.
  • k0 - The vacuum wavevector.
  • k - The parallel component of the wavevector.
Returns:

The propagation transfer matrix for the layer.

pub fn matrix_interface_te(n1: f64, n2: f64, k0: f64, k: f64) -> TransferMatrix

Creates the transfer matrix representing the interafce between two layers for TE polarization.

Arguments:
  • n1 - The refractive index of the first layer.
  • n2 - The refractive index of the second layer.
  • k0 - The vacuum wavevector.
  • k - The parallel component of the wavevector.
Returns:

The interface transfer matrix for TE polarization.

pub fn matrix_interface_tm(n1: f64, n2: f64, k0: f64, k: f64) -> TransferMatrix

Creates the transfer matrix representing the interafce between two layers for TM polarization./

Arguments:
  • n1 - The refractive index of the first layer.
  • n2 - The refractive index of the second layer.
  • k0 - The vacuum wavevector.
  • k - The parallel component of the wavevector.
Returns:

The interface transfer matrix for TM polarization.

pub fn matrix_interface( n1: f64, n2: f64, k0: f64, k: f64, polarization: Polarization, ) -> TransferMatrix

Creates the transfer matrix representing the interafce between two layers..

Arguments:
  • n1 - The refractive index of the first layer.
  • n2 - The refractive index of the second layer.
  • k0 - The vacuum wavevector.
  • k - The parallel component of the wavevector.
  • polarization - The polarization of the light.
Returns:

The interface transfer matrix.

pub fn multiply( &self, coefficient_vector: &LayerCoefficientVector, ) -> LayerCoefficientVector

Calculates the modal coefficient on the right of the matrix starting from the ones on the left.

Arguments:
  • coefficient_vector - The modal coefficient on the left of the matrix.
Returns:

The modal coefficient on the right of the matrix.